==> vue-hljs-with-line-number-1.0.6.tgz: package/index.js <==
'use strict';

var hljs = require('highlight.js');
hljs.lineNumbersBlock = require('./hljs-line-number');
// import hljs from 'highlight.js';

var vueHighlightJS = {};
vueHighlightJS.install = function install(Vue) {
  Vue.directive('hljs', {
    deep: true,
    bind: function bind(el, binding) {
      // on first bind, highlight all targets
      var targets = el.querySelectorAll('code');
      var target;
      var i;
      
      let element = document.createElement('div');
      for (i = 0; i < targets.length; i += 1) {
        target = targets[i];

        let code = target.textContent;
        if (typeof binding.value === 'string') {
          // if a value is directly assigned to the directive, use this
          // instead of the element content.
          code = binding.value;
        }

        element.innerHTML = hljs.highlightAuto(`<span>${code}</span>`).value
        hljs.lineNumbersBlock(target, element, {
          singleLine: code.split('\n').length == 1
        });
      }
    },
    componentUpdated: function componentUpdated(el, binding) {
      // after an update, re-fill the content and then highlight
      var targets = el.querySelectorAll('code');
      var target;
      var i;

      let element = document.createElement('div');
      for (i = 0; i < targets.length; i += 1) {
        target = targets[i];
        let code = target.textContent;
        if (typeof binding.value === 'string') {
          code = binding.value;
        }
        element.innerHTML = hljs.highlightAuto(`<span>${code}</span>`).value
        hljs.lineNumbersBlock(target, element, {
          singleLine: code.split('\n').length == 1
        });
      }
    }
  });
};

module.exports = vueHighlightJS;

==> vue-hljs-with-line-number-1.0.7.tgz: package/index.js <==
'use strict';

var hljs = require('highlight.js');
hljs.lineNumbersBlock = require('./hljs-line-number');
// import hljs from 'highlight.js';

var vueHighlightJS = {};
vueHighlightJS.install = function install(Vue) {
  Vue.directive('hljs', {
    deep: true,
    bind: function bind(el, binding) {
      // on first bind, highlight all targets
      var targets = el.querySelectorAll('code');
      var target;
      var i;
      
      let element = document.createElement('div');
      for (i = 0; i < targets.length; i += 1) {
        target = targets[i];

        let code = target.textContent;
        if (typeof binding.value === 'string') {
          // if a value is directly assigned to the directive, use this
          // instead of the element content.
          code = binding.value;
        }

        element.innerHTML = hljs.highlightAuto(`${code}`).value
        hljs.lineNumbersBlock(target, element, {
          singleLine: code.split('\n').length == 1
        });
      }
    },
    componentUpdated: function componentUpdated(el, binding) {
      // after an update, re-fill the content and then highlight
      var targets = el.querySelectorAll('code');
      var target;
      var i;

      let element = document.createElement('div');
      for (i = 0; i < targets.length; i += 1) {
        target = targets[i];
        let code = target.textContent;
        if (typeof binding.value === 'string') {
          code = binding.value;
        }
        element.innerHTML = hljs.highlightAuto(`${code}`).value
        hljs.lineNumbersBlock(target, element, {
          singleLine: code.split('\n').length == 1
        });
      }
    }
  });
};

module.exports = vueHighlightJS;
